@@ -27,6 +27,7 @@ describe 'vitrage' do
         is_expected.to contain_vitrage_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_vitrage_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_vitrage_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
@@ -52,6 +53,7 @@ describe 'vitrage' do
           :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
+          :rabbit_heartbeat_in_pthread        => true,
           :kombu_compression                  => 'gzip',
           :kombu_failover_strategy            => 'shuffle',
           :package_ensure                     => '2012.1.1-15.el6',
@@ -69,6 +71,7 @@ describe 'vitrage' do
         is_expected.to contain_vitrage_config('DEFAULT/control_exchange').with_value('vitrage')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
+        is_expected.to contain_vitrage_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip')
         is_expected.to contain_vitrage_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('shuffle')
       end
@@ -85,7 +88,7 @@ describe 'vitrage' do
         before { params.merge!( :notification_driver => ['messaging', 'messagingv2']) }
 
         it { is_expected.to contain_vitrage_config('oslo_messaging_notifications/driver').with_value(
-          'messaging,messagingv2'
+          ['messaging', 'messagingv2']
         ) }
       end
 
